<?php
/*
* File:     FlagCollection.php
* Category: Collection
* Author:   M. Goldenbaum
* Created:  21.07.18 23:10
* Updated:  -
*
* Description:
*  -
*/

namespace Webklex\PHPIMAP\Support;

use Illuminate\Support\Collection;

/**
 * Class FlagCollection
 *
 * @package Webklex\PHPIMAP\Support
 * @implements Collection<string, string>
 */
class FlagCollection extends PaginatedCollection {

}